# Example: Pfizer-BioNTech COVID-19 vaccine

c.table <- array(data = c(8, 162, 17403, 17349), dim = c(2,2), dimnames =
    list(Treatment = c("Vaccine", "Placebo"), Outcome = c("Positive", "Negative")))
c.table

pi.hat.table <- c.table/rowSums(c.table)
pi.hat.table

pi.hat1 <- pi.hat.table[1,1]
pi.hat2 <- pi.hat.table[2,1]


################################################################################
# Relative risk

  round(pi.hat1/pi.hat2, 4)
  round(1/(pi.hat1/pi.hat2), 4)


  # Wald confidence interval
  alpha <- 0.05
  var.log.RR <- 1/c.table[1,1] - 1/sum(c.table[1,]) + 1/c.table[2,1] - 1/sum(c.table[2,])
  RR.ci <- exp(log(pi.hat1/pi.hat2) + qnorm(p = c(alpha/2, 1-alpha/2)) * sqrt(var.log.RR))
  round(RR.ci, 4)
  rev(round(1/RR.ci, 4))  # inverted

  # Equivalent way to get variance
  # n1 <- sum(c.table[1,])
  # n2 <- sum(c.table[2,])
  # var.log.rr <- (1-pi.hat1)/(n1*pi.hat1) + (1-pi.hat2)/(n2*pi.hat2)


  # Function to calculate relative risk
  RR <- function(data, alpha = 0.05, digits = 4) {
    n1 <- sum(data[1,])
    n2 <- sum(data[2,])
    pi.hat.table <- data/rowSums(data)
    pi.hat1 <- pi.hat.table[1,1]
    pi.hat2 <- pi.hat.table[2,1]
    RR.hat <- pi.hat1/pi.hat2
    var.log.RR <- 1/data[1,1] - 1/sum(data[1,]) + 1/data[2,1] - 1/sum(data[2,])
    RR.CI <- exp(log(pi.hat1/pi.hat2) + qnorm(p = c(alpha/2, 1-alpha/2)) * sqrt(var.log.RR))
    round(data.frame(Estimate = RR.hat, Lower = RR.CI[1], Upper = RR.CI[2], row.names = ""), digits)
  }

  RR(data = c.table, alpha = 0.05, digits = 4)
  RR(data = c.table)  # Use defaults
  save.res <- RR(data = c.table, alpha = 0.05)
  save.res[,1]
  save.res[,2:3]
  save.res$Estimate
  save.res$Lower
  save.res$Upper

  # There are alternative ways to return the results from RR:
  # 1) list(RR = round(RR, digits), CI = round(ci, digits))
  # 2) matrix(data = round(c(RR, ci), digits), nrow = 1, ncol = 3,
  #     dimnames = list(NULL, c("Estimate", "Lower", "Upper")))
  # This code can replace the last line within the function.



################################################################################
# Odds ratio

  OR.hat <- c.table[1,1] * c.table[2,2] / (c.table[2,1] * c.table[1,2])
  round(OR.hat, 4)
  round(1/OR.hat, 4)

  alpha <- 0.05
  var.log.OR <- 1/c.table[1,1] + 1/c.table[1,2] + 1/c.table[2,1] + 1/c.table[2,2]
  OR.CI <- exp(log(OR.hat) + qnorm(p = c(alpha/2, 1-alpha/2)) * sqrt(var.log.OR))
  round(OR.CI, 4)
  rev(round(1/OR.CI, 4))









#