# Example: Simulate counts in a contingency table

pi1 <- 0.2
pi2 <- 0.4
n1 <- 10
n2 <- 10

set.seed(8191)
w1 <- rbinom(n = 1, size = n1, prob = pi1)
w2 <- rbinom(n = 1, size = n2, prob = pi2)

c.table <- array(data = c(w1, w2, n1-w1, n2-w2), dim = c(2,2), dimnames = list(Group = c(1,2),
             Response = c("Success", "Failure")))
c.table
c.table[1,1]  # w1
c.table["1", "Success"]  # w1
c.table[1,2]  # n1-w1
c.table[1,]  # w1 and n1-w1
c.table["1", ]  # w1
sum(c.table[1,])  # n1

# Alternative ways to find marginal counts
addmargins(c.table)  # Shows table with marginal counts
marginSums(c.table)  # n+
marginSums(c.table, margin = 1)  # n1 and n2
rowSums(c.table)  # n1 and n2
marginSums(c.table, margin = 2)  # w+ and n+ - w+
colSums(c.table)  # w+ and n+ - w+

list(Group = c(1,2), Response = c("Success", "Failure"))

###########################################################################
# Simulate 1,000 contingency tables

set.seed(8191)
w1 <- rbinom(n = 1000, size = n1, prob = pi1)
w2 <- rbinom(n = 1000, size = n2, prob = pi2)

# Table #1
c.table1 <- array(data = c(w1[1], w2[1], n1-w1[1], n2-w2[1]), dim = c(2,2), dimnames = list(Group = c(1,2),
             Response = c("Success", "Failure")))
c.table1
c.table1[1,1]  # w1
c.table1[1,2]  # n1-w1
c.table1[1,]  # w1 and n1-w1
sum(c.table1[1,])  # n1



# Table #5
c.table5 <- array(data = c(w1[5], w2[5], n1-w1[5], n2-w2[5]), dim = c(2,2), dimnames = list(Group = c(1,2),
             Response = c(1, 2)))
c.table5

pihat1 <- w1/n1
mean(pihat1)  # Close to pi1 as expected

pihat2 <- w2/n2
mean(pihat2)  # Close to pi2 as expected









#

