# Example: COVID-19 vaccine clinical trial, loglinear model


c.table <- array(data = c(8, 162, 17403, 17349), dim = c(2,2), dimnames = list(Treatment = c("Vaccine", "Placebo"), Outcome = c("Positive", "Negative")))
c.table

# Convert data to data frame for glm()
all.data <- as.data.frame(as.table(c.table))
all.data
levels(all.data$Treatment)
levels(all.data$Outcome)


# Fit Poisson Regression
# options(width = 60)  # Needed for book formatting
M1 <- glm(formula = Freq ~ Treatment*Outcome, family = poisson(link = "log"), data = all.data)
summary(M1)
predict(object = M1, type = "response")

# Odds ratio estimate and confidence intervals
#   Easy to do because just one parameter controls OR
round(exp(M1$coefficients[4]), digits = 3)
# LR CI
inter <- confint(object = M1, parm = "TreatmentPlacebo:OutcomeNegative")
round(exp(inter), digits = 3)
# Wald CI
round(exp(confint.default(object = M1, parm = "TreatmentPlacebo:OutcomeNegative")), digits = 3)

# Show Wald CI using emmeans
library(package = emmeans)
emm1 <- emmeans(object = M1, specs = ~ Treatment + Outcome)
emm1 # log-means for each combination
# "pairwise" takes difference of log-means 
#    for pairs of levels within a variable
# "interaction" repeats difference on differences (i.e., interaction term)
# options(width = 60)  # Needed for book formatting
con1 <- contrast(object = emm1, interaction = list("pairwise"))
confint(object = con1, type = "response")

#Test for H0: OR=1
library(package = car)
Anova(M1) 
