# Example: HIV screening via group testing

library(package = binGroup2)


################################################################################
# Equal probabilities (non-informative group testing)

  pitilde <- 0.0041
  I <- 20

  # pitilde.ex1 <- rep(x = pi, times = I)
  group.member <- matrix(data = c(rep(1, times = I), 1:I), nrow = 2, ncol = 20,
    byrow = TRUE)
  options(width = 65) # Used for book
  group.member
  options(width = 80)
  test.vlow <- opChar1(algorithm = "D2", p = pitilde, Se = 0.967, Sp = 0.976,
     hier.config = group.member)
  summary(test.vlow)

  # This also works
  pitilde.vec <- rep(x = pitilde, times = I)
  test.vlow2 <- opChar1(algorithm = "D2", probabilities = pitilde.vec, Se = 0.967, Sp = 0.976,
     hier.config = group.member)
  summary(test.vlow2)

  test.low <- opChar1(algorithm = "D2", p = pitilde, Se = 0.884, Sp = 0.976,
     hier.config = group.member)
  summary(test.low)

  test.norm <- opChar1(algorithm = "D2", p = pitilde, Se = 0.653, Sp = 0.976,
     hier.config = group.member)
  summary(test.norm)

  # Expected number of tests per individual
  data.frame(CD4.vlow = test.vlow$ET/I, CD4.low = test.low$ET/I,
    CD4.norm = test.norm$ET/I)

  # Find OTC
  save.config.vlow <- OTC1(algorithm = "D2", p = pitilde, Se = 0.967, Sp = 0.976,
    group.sz = 3:30, obj.fn = "ET")
  summary(save.config.vlow)

  # Proportion reduction in tests from using OTC
  (test.vlow$ET/I - save.config.vlow$opt.ET$value)/ (test.vlow$ET/I)

  # Other CD4 levels
  save.config.low <- OTC1(algorithm = "D2", p = pitilde, Se = 0.884, Sp = 0.976, group.sz = 3:30, obj.fn = "ET")
  save.config.norm <- OTC1(algorithm = "D2", p = pitilde, Se = 0.653, Sp = 0.976, group.sz = 3:30, obj.fn = "ET")


################################################################################
# Informative group testing

  # Example set of expected order statistics
  p.beta1 <- expectOrderBeta(p = pitilde, alpha = 0.5, size = 35)
  head(p.beta1, n = 4)
  tail(p.beta1, n = 4)

  options(width = 50)
  # Find OTC with a = 0.5
  PSOD.0.5 <- OTC1(algorithm = "ID2", p = pitilde, Se = 0.967, Sp = 0.976,
    group.sz = 35, obj.fn = "ET", alpha = 0.5)
  summary(PSOD.0.5)

  # Reproduce results using expected order statistics
  group.member <- matrix(data = c(rep(1, times = 25), rep(2, times = 10),
    1:25, 1:10), nrow = 2, ncol = 35, byrow = TRUE)
  PSOD.0.5.rep <- opChar1(algorithm = "ID2", probabilities = p.beta1, Se = 0.967, Sp = 0.976,
     hier.config = group.member)
  PSOD.0.5.rep$ET
  PSOD.0.5.rep$Config

  summary(PSOD.0.5.rep)

  # Reduction in expected number of tests per individual
  (save.config.vlow$opt.ET$value - PSOD.0.5$opt.ET$value)/save.config.vlow$opt.ET$value









#